<?php

namespace Drupal\speakeasy\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure SpeakEasy settings for this site.
 */
class SpeakEasySettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'speakeasy_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'speakeasy.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('speakeasy.settings');

    $form['default_voice_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Default Voice Name'),
      '#description' => $this->t('Name of the default voice to use site-wide. Leave blank for browser default.'),
      '#default_value' => $config->get('default_voice_name'),
    ];

    $form['default_rate'] = [
      '#type' => 'number',
      '#title' => $this->t('Default Rate'),
      '#description' => $this->t('Default speech rate (0.1 to 10).'),
      '#default_value' => $config->get('default_rate') ?: 1,
      '#step' => 0.1,
      '#min' => 0.1,
      '#max' => 10,
    ];

    $form['default_pitch'] = [
      '#type' => 'number',
      '#title' => $this->t('Default Pitch'),
      '#description' => $this->t('Default speech pitch (0 to 2).'),
      '#default_value' => $config->get('default_pitch') ?: 1,
      '#step' => 0.1,
      '#min' => 0,
      '#max' => 2,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('speakeasy.settings')
      ->set('default_voice_name', $form_state->getValue('default_voice_name'))
      ->set('default_rate', $form_state->getValue('default_rate'))
      ->set('default_pitch', $form_state->getValue('default_pitch'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
